Index: components/nacl/browser/nacl_file_host.h |
diff --git a/components/nacl/browser/nacl_file_host.h b/components/nacl/browser/nacl_file_host.h |
index 11f533378dbe667aac154883918dadacea7fe742..d3953f35a136a6427671f529d2ad86166c81df60 100644 |
--- a/components/nacl/browser/nacl_file_host.h |
+++ b/components/nacl/browser/nacl_file_host.h |
@@ -6,6 +6,7 @@ |
#define COMPONENTS_NACL_BROWSER_NACL_FILE_HOST_H_ |
#include <string> |
+#include <vector> |
#include "base/memory/ref_counted.h" |
@@ -41,11 +42,12 @@ void GetReadonlyPnaclFd( |
bool PnaclCanOpenFile(const std::string& filename, |
base::FilePath* file_to_open); |
-// Opens a NaCl executable file for reading and executing. |
-void OpenNaClExecutable( |
+// Opens NaCl resource files for reading and/or executing. |
+void OpenNaClResources( |
scoped_refptr<nacl::NaClHostMessageFilter> nacl_host_message_filter, |
int render_view_id, |
- const GURL& file_url, |
+ const GURL& executable_file_url, |
+ const std::vector<GURL>& resource_urls, |
IPC::Message* reply_msg); |
} // namespace nacl_file_host |